//
//  ScanBarCodeViewController.m
//  SampleScanBarCode
//
//  Created by elcaptain1 on 6/3/16.
//  Copyright © 2016 Tanuja. All rights reserved.
//

#import "ScanBarCodeViewController.h"

@interface ScanBarCodeViewController ()
{
    AVCaptureSession *_captureSession;
    AVCaptureDevice *_captureDevice;
    AVCaptureDeviceInput *_captureDeviceInput;
    AVCaptureMetadataOutput *_captureMetadataOutput;
    AVCaptureVideoPreviewLayer *_prevLayer;
    
    UIView *_highlightedView;
    UILabel *_lblMessage;
}
@end

@implementation ScanBarCodeViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    _highlightedView = [[UIView alloc] init];
    _highlightedView.autoresizingMask = UIViewAutoresizingFlexibleTopMargin|UIViewAutoresizingFlexibleLeftMargin|UIViewAutoresizingFlexibleRightMargin|UIViewAutoresizingFlexibleBottomMargin;
    _highlightedView.layer.borderColor = [UIColor greenColor].CGColor;
    _highlightedView.layer.borderWidth = 3;
    [self.view addSubview:_highlightedView];
    
    _lblMessage = [[UILabel alloc] init];
    _lblMessage.frame = CGRectMake(0, self.view.bounds.size.height - 40, self.view.bounds.size.width, 40);
    _lblMessage.autoresizingMask = UIViewAutoresizingFlexibleTopMargin;
    _lblMessage.backgroundColor = [UIColor colorWithWhite:0.15 alpha:0.65];
    _lblMessage.textColor = [UIColor whiteColor];
    _lblMessage.textAlignment = NSTextAlignmentCenter;
    _lblMessage.text = message;
    [self.view addSubview:_lblMessage];
    
    _captureSession = [[AVCaptureSession alloc] init];
    _captureDevice = [AVCaptureDevice defaultDeviceWithMediaType:AVMediaTypeVideo];
    NSError *error = nil;
    
    _captureDeviceInput = [AVCaptureDeviceInput deviceInputWithDevice:_captureDevice error:&error];
    if (_captureDeviceInput) {
        [_captureSession addInput:_captureDeviceInput];
    } else {
        NSLog(@"Error: %@", error);
    }
    
    _captureMetadataOutput = [[AVCaptureMetadataOutput alloc] init];
    [_captureMetadataOutput setMetadataObjectsDelegate:self queue:dispatch_get_main_queue()];
    [_captureSession addOutput:_captureMetadataOutput];
    
    _captureMetadataOutput.metadataObjectTypes = [_captureMetadataOutput availableMetadataObjectTypes];
    
    _prevLayer = [AVCaptureVideoPreviewLayer layerWithSession:_captureSession];
    _prevLayer.frame = self.view.bounds;
    _prevLayer.videoGravity = AVLayerVideoGravityResizeAspectFill;
    [self.view.layer addSublayer:_prevLayer];
    
    [_captureSession startRunning];
    
    [self.view bringSubviewToFront:_highlightedView];
    [self.view bringSubviewToFront:_lblMessage];
    // Do any additional setup after loading the view.
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

- (void)captureOutput:(AVCaptureOutput *)captureOutput didOutputMetadataObjects:(NSArray *)metadataObjects fromConnection:(AVCaptureConnection *)connection
{
    CGRect highlightViewRect = CGRectZero;
    AVMetadataMachineReadableCodeObject *barCodeObject;
    NSString *detectionString = nil;
    NSArray *barCodeTypes = @[AVMetadataObjectTypeUPCECode, AVMetadataObjectTypeCode39Code, AVMetadataObjectTypeCode39Mod43Code,
                              AVMetadataObjectTypeEAN13Code, AVMetadataObjectTypeEAN8Code, AVMetadataObjectTypeCode93Code, AVMetadataObjectTypeCode128Code,
                              AVMetadataObjectTypePDF417Code, AVMetadataObjectTypeQRCode, AVMetadataObjectTypeAztecCode];
    
    for (AVMetadataObject *metadata in metadataObjects) {
        for (NSString *type in barCodeTypes) {
            if ([metadata.type isEqualToString:type])
            {
                barCodeObject = (AVMetadataMachineReadableCodeObject *)[_prevLayer transformedMetadataObjectForMetadataObject:(AVMetadataMachineReadableCodeObject *)metadata];
                NSLog(@"%@",barCodeObject);
                highlightViewRect = barCodeObject.bounds;
                detectionString = [(AVMetadataMachineReadableCodeObject *)metadata stringValue];
                NSLog(@"%@",detectionString);
                break;
            }
        }
        
        if (detectionString != nil)
        {
            _lblMessage.text = detectionString;
            break;
        }
        else
            _lblMessage.text = message;
    }
    
    _highlightedView.frame = highlightViewRect;
}
/*
#pragma mark - Navigation

// In a storyboard-based application, you will often want to do a little preparation before navigation
- (void)prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender {
    // Get the new view controller using [segue destinationViewController].
    // Pass the selected object to the new view controller.
}
*/

@end
